
TODO_10_72_28_05: Support `help` for any number of commands.

It also applies to `intercept`.

Currently, the issue is that delegators use `next_interp_plugin_instance_id` fixed to single interp id.
But that delegator may be unrelated to the tree used by another command (and another interp id).

General idea: configure it for different abs tree path (which should point to one of the interp id)
instead of interp id.

Extended idea: use global tree (g-tree) = single config place where all interp id and functions are plugged into.
Instead of configuring parts of the tree (sub-trees) under different plugins.
It should be made convenient to see the whole picture in single place
(and that tree is used as config for the plugins).
Think how to encode the tree via YAML for both func ids and interp ids (it seems it should contain both).
